#!/usr/bin/env python3
# -*- encoding: utf-8 -*-
"""
@File    :   tamil.py
@Path    :   agrothon/tgbot/translations/
@Time    :   2021/05/24
@Author  :   Sreenivas Pakyala
@Version :   1.2.7
@Contact :   ckvbalusu@gmail.com
@Desc    :   Tamil translations
"""


class Language(object):
    # Main Menu
    MAIN_MENU = "<b>முதன்மை பட்டியல்</b>"

    # Open Weather
    WEATHER_FETCH = "விவரங்களைப் பெறுதல் தயவுசெய்து காத்திருங்கள்"
    WEATHER = """
<b>📍 இடம் :</b><code> {}</code>
<b>🌡️ வெப்ப நிலை : </b><code>{} °C</code>
<b>💨 அழுத்தம் : </b><code>{} Pa</code>
<b>💧 ஈரப்பதம் : </b><code>{} g.m-3</code>
<b>⛅ வானிலை : </b><code>{}</code>
"""
    WEATHER_ERR = "<b>பிழை ஏற்பட்டது, பதில் : <code>{}</code> </b>"

    # Button Callbacks

    MOISTURE = "ஈரம்"
    HUMIDITY = "ஈரப்பதம்"
    TEMPERATURE = "வெப்ப நிலை"
    RAIN = "மழைக்கால நிலை"
    PUMP_STATUS = "பம்ப் நிலை"
    COMPLETE_INFO = "முழுமையான தகவல்"
    QUIT = "விட்டுவிட"
    PUMP_OFF = "அனைத்து விடு"
    PUMP_ON = "மாறவும்"
    BACK = "மீண்டும்"
    BOT_PRED = "பாட் ப்ரிடிக்டனை இயக்கவும்"
    REFRESH = "நிலையை புதுப்பிக்கவும்"

    MOISTURE_SENSOR = """<b>💧 மண்ணில் ஈரப்பதம் (சென்சார் {}): </b><code> {}%</code>\n"""
    MOISTURE_RESP = """<b>🕒 கடைசியாக புதுப்பிக்கப்பட்டது: </b><code> {}</code>
<b>🕒 கடைசியாக படித்தது: </b><code> {}</code>
"""
    HUMID_RESP = """
<b>⛅ புலத்தில் ஈரப்பதம் : </b><code> {}%</code>
<b>🕒 கடைசியாக புதுப்பிக்கப்பட்டது: </b><code> {}</code>
<b>🕒 கடைசியாக படித்தது: </b><code> {}</code>
"""
    TEMPE_RESP = """
<b>🌡️ புலத்தில் தற்காலிகம் : </b><code> {}°C</code>
<b>🕒 கடைசியாக புதுப்பிக்கப்பட்டது: </b><code> {}</code>
<b>🕒 கடைசியாக படித்தத: </b><code> {}</code>
"""
    RAIN_YES_RESP = """
<b>பண்ணையில் மழை பெய்கிறது 🌧️ </b>

"""
    RAIN_NO_RESP = """
<b>பண்ணையில் மழை பெய்யவில்லை 🌞</b>

"""
    COMPLETE_MOISTURE = """<b>💧 ஈரம் (சென்சார் {}): </b><code> {}%</code>\n"""
    COMPLETE_RESP = """<b>⛅ ஈரப்பதம் : </b><code> {}%</code>
<b>🌡️ வெப்ப நில : </b><code> {}°C</code>
<b>⛏️ பம்ப் இருக்க வேண்டும் (சென்சார் {}): </b><code> {}</code>
<b>🕒 கடைசியாக புதுப்பிக்கப்பட்டது: </b><code> {}</code>
<b>🕒 கடைசியாக படித்தது: </b><code> {}</code>
"""
    # Pump
    PUMP_SWITCHED_ON = """
<b>பம்ப் இயங்குகிறது</b>
இயக்கப்பட்டது <code> {}</code>
கடைசி சோதனை : <code> {}</code>
"""

    PUMP_SWITCHED_OFF = """
<b>பம்ப் முடக்கப்பட்டுள்ளது</b>
ஆல் மாற்றப்பட்டது <code> {}</code>
கடைசி சோதனை : <code> {}</code>
"""

    BOT_ACTIVATED = """<b>🤖 போட் பயன்முறை செயல்படுத்தப்பட்டது</b>
இப்போது நீங்கள் உட்கார்ந்து ஓய்வெடுக்கலாம் மற்றும் உங்கள் 🤖 பண்ணையை நிர்வகிக்க போட் அனுமதிக்கலாம் 🚜
"""
    PUMP_BTN_ON = """
<b> ✅ இயங்கும் நிலை மாற்றப்பட்டது </b>
இயக்கப்பட்டது<code> User</code>
"""

    PUMP_BTN_OFF = """
<b> ✅ இயங்கும் நிலை மாற்றப்பட்டது </b>
ஆல் மாற்றப்பட்டது<code> User</code>
"""

    SETTINGS = "⚙️ அமைப்புகள் ⚙️"
    LANG = "🌐 மொழியை மாற்றுங்கள் 🌐"
    SELECT_LANG = "விருப்பமான மொழியைத் தேர்ந்தெடுக்கவும்"
    LANG_CHANGED = "மொழி ஆங்கிலத்திற்கு மாற்றப்பட்டுள்ளது"
    OBJECTS = "பொருள்கள்"
    DET_NO = "கண்டறியப்பட்டது"
    ALERT_MESSAGE = """
<b>ஊடுருவும் நபர்கள் கண்டறியப்பட்டுள்ளனர் </b>
<b>இல் கண்டறியப்பட்டது</b> : <code> {}</code>
<b>பொருள்கள் எதுவும் கண்டறியப்படவில்லை</b> : <code> {}</code>
<b>மக்கள் யாரும் கண்டறியப்படவில்லை</b> : <code> {}</code>

<pre>{}</pre>
"""
    MONTHS = [
        "ஏப்ரல்",
        "மே",
        "ஜூன்",
        "ஜூலை",
        "ஆகஸ்ட்",
        "செப்டம்பர்",
        "அக்டோபர்",
        "நவம்பர்",
        "டிசம்பர்",
    ]
    MONTH = "மாதம்"
    RAINFALL = "மழைப்பொழிவு(இல் {})"
    RAIN_PREDICT = """
<b>இந்த ஆண்டிற்கான மழைப்பொழிவு கணிப்புகள்</b>
<b>நிலை</b>: <code> {}</code>
<b>மாவட்டம் </b>: <code> {}</code>

<pre>{}</pre>
"""
    RAIN_PREDICT_ERR = """
கணிக்கும் போது பிழை
"""
    IMAGE_MESSAGE = """
<b>பொருள்கள் கண்டறியப்பட்டுள்ளன </b>
<b>பொருள்கள் எதுவும் கண்டறியப்படவில்லை</b> : <code> {}</code>
<b>மக்கள் யாரும் கண்டறியப்படவில்லை</b> : <code> {}</code>

<pre>{}</pre>
"""
    ERR_IMAGE_RESPONSE = """
<b>படத்தில் எதுவும் காணப்படவில்லை</b>
"""
    PRED_PUMP_OFF = "மஆஃப்ு"
    PRED_PUMP_ON = "ஆன்"
    STATS = """
<b>முடிந்தநேரம் :</b><code> {}</code>
<b>வட்டு அளவு :</b><code> {}</code>
<b>பயன்படுத்தப்பட்டது :</b><code> {}</code>
<b>இலவசம் :</b><code> {}</code>
<b>CPU பயன்பாடு :</b><code> {}%</code>
<b>RAM பயன்பாடு :</b><code> {}%</code>
<b>பதிவேற்றப்பட்டது :</b><code> {}</code>
<b>பதிவிறக்கம் செய்யப்பட்டது :</b><code> {}</code>
"""
    DL_TG = "டெலிகிராமிலிருந்து பதிவிறக்குகிறது"
    PROC_IMAGE = (
        "Dசொந்தமாக ஏற்றப்பட்டது, பொருள்களைக் கண்டறிதல் தயவுசெய்து காத்திருங்கள் ..."
    )
    RESTART = "மறுதொடக்கம், தயவுசெய்து காத்திருங்கள் ...."
    RESTART_DONE = "மீண்டும் தொடங்கப்பட்டது வெற்றிகரமாக!"
    RESTART_CALLBACK = "மறுதொடக்கம்"
    WEATHER_FETCHING = "வானிலை பெறுகிறது, தயவுசெய்து காத்திருங்கள்"
    HELP_MESSAGE = """
<code>/{}</code> : உங்கள் நகரத்தின் வானிலை நிலை
<code>/{}</code> : உங்கள் பிராந்தியத்தின் மழையை கணிக்கவும்
<code>/{}</code> : உங்கள் புல நிலையைப் பெற்று உங்கள் பம்பை நிர்வகிக்கவும்
<code>/{}</code> : உங்கள் போட் அமைப்புகளை மாற்றவும்
<code>/{}</code> : சேவையக புள்ளிவிவரங்களைப் பெறுங்கள்
<code>/{}</code> : பிங் சரிபார்க்கவும்
<code>/{}</code> : சேவையகத்தின் பதிவைப் பெறுங்கள்
<code>/{}</code> : சேவையகத்தை மறுதொடக்கம் செய்யுங்கள்
<code>/{}</code> : இந்த செய்தியைப் பெற

<code>ஒரு படத்தில் உள்ள பொருட்களைக் கண்டறிய படத்தை அனுப்பவும்</code>
"""
    START = """
ஏய், நான் <code>அக்ரோத்தான்</code>

 - உங்கள் பண்ணையை கண்காணிக்கலாம்
 - பம்ப் நிலையை ஆன் அல்லது ஆஃப் என மாற்றவும்
 - வானிலை கிடைக்கும்
 - ஒரு படத்தில் பொருள்களைக் கண்டறியவும்
 - உங்கள் பிராந்தியத்திற்கு மழையை கணிக்கவும்
"""
    PING_START = "பிங் தொடங்குகிறது"
    PING_FINAL = "அளவிடப்பட்ட பிங் : {}"
    LANG_SET = "விருப்பமான மொழி தொகுப்பு வெற்றிகரமாக"
    PUMP_STATUS_ON = "மீது"
    PUMP_STATUS_OFF = "ஆஃப்"
